@@ -1,5 +1,5 @@
 package Starch::Store;
-$Starch::Store::VERSION = '0.01';
+$Starch::Store::VERSION = '0.02';
 =head1 NAME
 
 Starch::Store - Base role for Starch stores.
@@ -81,7 +81,7 @@ if the state's expires is larger.
 
 has max_expires => (
     is  => 'ro',
-    isa => PositiveOrZeroInt | Undef,
+    isa => (PositiveOrZeroInt) | Undef,
 );
 
 =head1 ATTRIBUTES
